@@ -1,17 +1,34 @@
 ﻿
 
 
-__version__ = "0.2021.3.2"
+__version__ = "0.2021.12.8"
 
 
 
-from .IDCounter import IDCounter
-from .RollOverLogFile import RollOverLogFile
+from .impl.IDCounter import IDCounter
+from .impl.RollOverLogFile import RollOverLogFile
+from .impl.LogStats import LogStats
+
+
 
 from .ExceptionInChildContextException import ExceptionInChildContextException
 from .EnumLogLevel import EnumLogLevel
-from .LogStats import LogStats
 
+
+
+from .fmt.AbstractTimeStampFormatter import AbstractTimeStampFormatter
+from .fmt.AbstractLogMessageFormatter import AbstractLogMessageFormatter
+
+from .fmt.DefaultTimeStampFormatter import DefaultTimeStampFormatter
+
+from .fmt.ColoredLogMessageFormatter import ColoredLogMessageFormatter, COLOR_LOG_MESSAGE_FORMATTER
+from .fmt.HTMLLogMessageFormatter import HTMLLogMessageFormatter, HTML_LOG_MESSAGE_FORMATTER
+from .fmt.JSONLogMessageFormatter import JSONLogMessageFormatter, JSON_LOG_MESSAGE_FORMATTER
+from .fmt.LogMessageFormatter import LogMessageFormatter, DEFAULT_LOG_MESSAGE_FORMATTER
+
+
+
+from .ILogger import ILogger
 from .AbstractLogger import AbstractLogger
 from .BufferLogger import BufferLogger
 from .ConsoleLogger import ConsoleLogger
@@ -24,12 +41,7 @@ from .NullLogger import NullLogger
 #from .SimpleFileLogger import SimpleFileLogger
 from .FileLogger import FileLogger
 from .StringListLogger import StringListLogger
-from .JSONLogger import JSONLogger
-
-from .AbstractLogMessageFormatter import AbstractLogMessageFormatter
-from .LogMessageFormatter import LogMessageFormatter, DEFAULT_LOG_MESSAGE_FORMATTER
-from .ColoredLogMessageFormatter import ColoredLogMessageFormatter, COLOR_LOG_MESSAGE_FORMATTER
-from .HTMLLogMessageFormatter import HTMLLogMessageFormatter, HTML_LOG_MESSAGE_FORMATTER
+from .JSONFileLogger import JSONFileLogger
 
 from .LoggerInstanceManager import LoggerInstanceManager
 
@@ -38,8 +50,3 @@ from .annotation_logDescend import logDescend
 from ._inst import instantiateLogMsgFormatter, instantiate
 from ._wrapMain import wrapMain
 
-
-
-
-
-
